You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tvm.apache.org by ma...@apache.org on 2021/11/16 19:59:42 UTC

[tvm] branch main updated: [ETHOSN] Cleanup of trademarks and registered trademarks (#9516)

This is an automated email from the ASF dual-hosted git repository.

manupa pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/tvm.git


The following commit(s) were added to refs/heads/main by this push:
     new 3f2ae34  [ETHOSN] Cleanup of trademarks and registered trademarks (#9516)
3f2ae34 is described below

commit 3f2ae347826e869b0cecbc70475832511f278bc3
Author: Leo-arm <52...@users.noreply.github.com>
AuthorDate: Tue Nov 16 19:59:19 2021 +0000

    [ETHOSN] Cleanup of trademarks and registered trademarks (#9516)
    
    Simple cleanup of comments and documentation, mainly for Arm(R) Ethos(TM)-N NPU related code.
---
 CMakeLists.txt                                                | 2 +-
 cmake/modules/contrib/EthosN.cmake                            | 8 ++++----
 cmake/utils/FindEthosN.cmake                                  | 8 ++++----
 python/tvm/relay/op/contrib/ethosn.py                         | 4 ++--
 python/tvm/testing/utils.py                                   | 4 ++--
 src/relay/backend/contrib/ethosn/codegen.cc                   | 4 ++--
 src/relay/backend/contrib/ethosn/codegen_ethosn.h             | 2 +-
 src/relay/backend/contrib/ethosn/ethosn_api.cc                | 4 ++++
 src/relay/backend/contrib/ethosn/ethosn_api.h                 | 4 ++++
 src/relay/backend/contrib/ethosn/ethosn_api_version.h         | 4 ++++
 src/runtime/contrib/ethosn/ethosn_device.cc                   | 2 +-
 src/runtime/contrib/ethosn/ethosn_device.h                    | 2 +-
 src/runtime/contrib/ethosn/ethosn_runtime.cc                  | 2 +-
 tests/python/contrib/test_ethosn/__init__.py                  | 2 +-
 tests/python/contrib/test_ethosn/infrastructure.py            | 2 +-
 tests/python/contrib/test_ethosn/test_addition.py             | 2 +-
 tests/python/contrib/test_ethosn/test_concatenate.py          | 2 +-
 tests/python/contrib/test_ethosn/test_constant_duplication.py | 2 +-
 tests/python/contrib/test_ethosn/test_conv2d.py               | 2 +-
 tests/python/contrib/test_ethosn/test_depth_to_space.py       | 2 +-
 tests/python/contrib/test_ethosn/test_fullyconnected.py       | 2 +-
 tests/python/contrib/test_ethosn/test_networks.py             | 2 +-
 tests/python/contrib/test_ethosn/test_partition_params.py     | 3 ++-
 tests/python/contrib/test_ethosn/test_pooling.py              | 2 +-
 tests/python/contrib/test_ethosn/test_relu.py                 | 2 +-
 tests/python/contrib/test_ethosn/test_reshape.py              | 2 +-
 tests/python/contrib/test_ethosn/test_sigmoid.py              | 2 +-
 tests/python/contrib/test_ethosn/test_split.py                | 2 +-
 tests/python/contrib/test_ethosn/test_topologies.py           | 3 ++-
 29 files changed, 49 insertions(+), 35 deletions(-)

diff --git a/CMakeLists.txt b/CMakeLists.txt
index 7293abb..4336ef2 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -47,7 +47,7 @@ tvm_option(HIDE_PRIVATE_SYMBOLS "Compile with -fvisibility=hidden." OFF)
 tvm_option(USE_TF_TVMDSOOP "Build with TensorFlow TVMDSOOp" OFF)
 tvm_option(USE_PT_TVMDSOOP "Build with PyTorch TVMDSOOp" OFF)
 tvm_option(USE_FALLBACK_STL_MAP "Use TVM's POD compatible Map" OFF)
-tvm_option(USE_ETHOSN "Build with Arm Ethos-N" OFF)
+tvm_option(USE_ETHOSN "Build with Arm(R) Ethos(TM)-N" OFF)
 tvm_option(USE_CMSISNN "Build with Arm CMSIS-NN" OFF)
 tvm_option(INDEX_DEFAULT_I64 "Defaults the index datatype to int64" ON)
 tvm_option(USE_LIBBACKTRACE "Build libbacktrace to supply linenumbers on stack traces" AUTO)
diff --git a/cmake/modules/contrib/EthosN.cmake b/cmake/modules/contrib/EthosN.cmake
index 44d2a2a..cc4d836 100644
--- a/cmake/modules/contrib/EthosN.cmake
+++ b/cmake/modules/contrib/EthosN.cmake
@@ -15,19 +15,19 @@
 # specific language governing permissions and limitations
 # under the License.
 
-# Arm Ethos-N rules
+# Arm(R) Ethos(TM)-N rules
 
 if(NOT USE_ETHOSN STREQUAL "OFF")
   find_ethosn(${USE_ETHOSN})
 
   if(NOT ETHOSN_FOUND)
-    message(FATAL_ERROR "Cannot find Ethos-N, USE_ETHOSN=" ${USE_ETHOSN})
+    message(FATAL_ERROR "Cannot find Arm(R) Ethos(TM)-N, USE_ETHOSN=" ${USE_ETHOSN})
 
   else()
     include_directories(SYSTEM ${ETHOSN_INCLUDE_DIRS})
     add_definitions(${ETHOSN_DEFINITIONS})
 
-    message(STATUS "Build with Ethos-N ${ETHOSN_PACKAGE_VERSION}")
+    message(STATUS "Build with Arm(R) Ethos(TM)-N ${ETHOSN_PACKAGE_VERSION}")
 
     file(GLOB ETHOSN_RUNTIME_CONTRIB_SRC
       CONFIGURE_DEPENDS src/runtime/contrib/ethosn/ethosn_runtime.cc
@@ -52,6 +52,6 @@ if(NOT USE_ETHOSN STREQUAL "OFF")
   endif(NOT ETHOSN_FOUND)
 else()
   if(USE_ETHOSN_HW)
-    message(FATAL_ERROR "Cannot enable Ethos-N HW if USE_ETHOSN=OFF")
+    message(FATAL_ERROR "Cannot enable Arm(R) Ethos(TM)-N HW if USE_ETHOSN=OFF")
   endif()
 endif(NOT USE_ETHOSN STREQUAL "OFF")
diff --git a/cmake/utils/FindEthosN.cmake b/cmake/utils/FindEthosN.cmake
index 26d00a4..1d5804e 100644
--- a/cmake/utils/FindEthosN.cmake
+++ b/cmake/utils/FindEthosN.cmake
@@ -16,7 +16,7 @@
 # under the License.
 
 #######################################################
-# Find Arm Ethos-N libraries
+# Find Arm(R) Ethos(TM)-N libraries
 #
 # Usage:
 #   find_ethosn(${USE_ETHOSN})
@@ -38,10 +38,10 @@ macro(find_ethosn use_ethosn)
   set(__use_ethosn ${use_ethosn})
   if(IS_DIRECTORY ${__use_ethosn})
     set(__ethosn_stack ${__use_ethosn})
-    message(STATUS "Arm Ethos-N driver stack PATH=" ${__use_ethosn})
+    message(STATUS "Arm(R) Ethos(TM)-N driver stack PATH=" ${__use_ethosn})
   elseif(IS_DIRECTORY $ENV{ETHOSN_STACK})
      set(__ethosn_stack $ENV{ETHOSN_STACK})
-    message(STATUS "Arm Ethos-N driver stack from env=" ${__use_ethosn})
+    message(STATUS "Arm(R) Ethos(TM)-N driver stack from env=" ${__use_ethosn})
   else()
      set(__ethosn_stack "")
   endif()
@@ -81,7 +81,7 @@ macro(find_ethosn use_ethosn)
 
   if(NOT ETHOSN_FOUND)
     if(${__use_ethosn} MATCHES ${IS_TRUE_PATTERN})
-      message(WARNING "No cmake find_package available for Arm Ethos-N")
+      message(WARNING "No cmake find_package available for Arm(R) Ethos(TM)-N")
     endif()
 
   # additional libraries
diff --git a/python/tvm/relay/op/contrib/ethosn.py b/python/tvm/relay/op/contrib/ethosn.py
index 412ae71..2480958 100644
--- a/python/tvm/relay/op/contrib/ethosn.py
+++ b/python/tvm/relay/op/contrib/ethosn.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 # pylint: disable=invalid-name, unused-argument
-"""Arm(R) Ethos(TM) -N NPU supported operators."""
+"""Arm(R) Ethos(TM)-N NPU supported operators."""
 from enum import Enum
 
 import tvm.ir
@@ -88,7 +88,7 @@ def partition_for_ethosn77(mod, params=None, **opts):
 
 def partition_for_ethosn78(mod, params=None, **opts):
     """Partition the graph greedily offloading supported
-    operators to Arm Ethos(TM)-N NPU.
+    operators to Arm Ethos-N NPU.
 
     Parameters
     ----------
diff --git a/src/relay/backend/contrib/ethosn/codegen_ethosn.h b/src/relay/backend/contrib/ethosn/codegen_ethosn.h
index 2795695..4927871 100644
--- a/src/relay/backend/contrib/ethosn/codegen_ethosn.h
+++ b/src/relay/backend/contrib/ethosn/codegen_ethosn.h
@@ -19,7 +19,7 @@
 
 /*!
  * \file src/relay/backend/contrib/ethosn/codegen_ethosn.h
- * \brief The Relay -> Ethos-N command stream compiler.
+ * \brief The Relay -> Arm(R) Ethos(TM)-N command stream compiler.
  */
 
 #ifndef TVM_RELAY_BACKEND_CONTRIB_ETHOSN_CODEGEN_ETHOSN_H_
diff --git a/src/relay/backend/contrib/ethosn/ethosn_api.cc b/src/relay/backend/contrib/ethosn/ethosn_api.cc
index 4587cdb..c300cae 100644
--- a/src/relay/backend/contrib/ethosn/ethosn_api.cc
+++ b/src/relay/backend/contrib/ethosn/ethosn_api.cc
@@ -16,6 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+/*!
+ * \file src/relay/backend/contrib/ethosn/ethosn_api.cc
+ * \brief The Relay -> Arm(R) Ethos(TM)-N command stream compiler.
+ */
 
 #include "ethosn_api.h"
 
diff --git a/src/relay/backend/contrib/ethosn/ethosn_api.h b/src/relay/backend/contrib/ethosn/ethosn_api.h
index e1b57b8..21f8f9c 100644
--- a/src/relay/backend/contrib/ethosn/ethosn_api.h
+++ b/src/relay/backend/contrib/ethosn/ethosn_api.h
@@ -16,6 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+/*!
+ * \file src/relay/backend/contrib/ethosn/ethosn_api.h
+ * \brief The Relay -> Arm(R) Ethos(TM)-N command stream compiler.
+ */
 
 #ifndef TVM_RELAY_BACKEND_CONTRIB_ETHOSN_ETHOSN_API_H_
 #define TVM_RELAY_BACKEND_CONTRIB_ETHOSN_ETHOSN_API_H_
diff --git a/src/relay/backend/contrib/ethosn/ethosn_api_version.h b/src/relay/backend/contrib/ethosn/ethosn_api_version.h
index ee6b43a..193b21f 100644
--- a/src/relay/backend/contrib/ethosn/ethosn_api_version.h
+++ b/src/relay/backend/contrib/ethosn/ethosn_api_version.h
@@ -17,6 +17,10 @@
  * under the License.
  */
 
+/*!
+ * \file src/relay/backend/contrib/ethosn/ethosn_api_version.h
+ * \brief Arm(R) Ethos(TM)-N versioning
+ */
 #include "ethosn_support_library/Support.hpp"
 
 #ifndef TVM_RELAY_BACKEND_CONTRIB_ETHOSN_ETHOSN_API_VERSION_H_
diff --git a/src/runtime/contrib/ethosn/ethosn_device.cc b/src/runtime/contrib/ethosn/ethosn_device.cc
index 0ffbee2..da7bdf6 100644
--- a/src/runtime/contrib/ethosn/ethosn_device.cc
+++ b/src/runtime/contrib/ethosn/ethosn_device.cc
@@ -19,7 +19,7 @@
 
 /*!
  * \file ethosn_device.cc
- * \brief Ethos-N NPU device integration.
+ * \brief Arm(R) Ethos(TM)-N NPU device integration.
  */
 
 #include <dlpack/dlpack.h>
diff --git a/src/runtime/contrib/ethosn/ethosn_device.h b/src/runtime/contrib/ethosn/ethosn_device.h
index d631d24..e2300ce 100644
--- a/src/runtime/contrib/ethosn/ethosn_device.h
+++ b/src/runtime/contrib/ethosn/ethosn_device.h
@@ -19,7 +19,7 @@
 
 /*!
  * \file ethosn_device.h
- * \brief Ethos-N NPU device integration.
+ * \brief Arm(R) Ethos(TM)-N NPU device integration.
  */
 #ifndef TVM_RUNTIME_CONTRIB_ETHOSN_ETHOSN_DEVICE_H_
 #define TVM_RUNTIME_CONTRIB_ETHOSN_ETHOSN_DEVICE_H_
diff --git a/src/runtime/contrib/ethosn/ethosn_runtime.cc b/src/runtime/contrib/ethosn/ethosn_runtime.cc
index 7fc4436..960c13d 100644
--- a/src/runtime/contrib/ethosn/ethosn_runtime.cc
+++ b/src/runtime/contrib/ethosn/ethosn_runtime.cc
@@ -19,7 +19,7 @@
 
 /*!
  * \file ethosn_runtime.cc
- * \brief Execution handling of Ethos-N command streams.
+ * \brief Execution handling of Arm(R) Ethos(TM)-N command streams.
  */
 
 #include "ethosn_runtime.h"
diff --git a/tests/python/contrib/test_ethosn/__init__.py b/tests/python/contrib/test_ethosn/__init__.py
index 109872e..be2b46d 100644
--- a/tests/python/contrib/test_ethosn/__init__.py
+++ b/tests/python/contrib/test_ethosn/__init__.py
@@ -14,4 +14,4 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Infrastructure and tests for EthosN"""
+"""Infrastructure and tests for Arm(R) Ethos(TM)-N"""
diff --git a/tests/python/contrib/test_ethosn/infrastructure.py b/tests/python/contrib/test_ethosn/infrastructure.py
index f16c37f..2bbea47 100644
--- a/tests/python/contrib/test_ethosn/infrastructure.py
+++ b/tests/python/contrib/test_ethosn/infrastructure.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Ethos-N test functions"""
+"""Arm(R) Ethos(TM)-N test functions"""
 
 from __future__ import absolute_import, print_function
 import tvm
diff --git a/tests/python/contrib/test_ethosn/test_addition.py b/tests/python/contrib/test_ethosn/test_addition.py
index 7e2a826..77271f7 100644
--- a/tests/python/contrib/test_ethosn/test_addition.py
+++ b/tests/python/contrib/test_ethosn/test_addition.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Ethos-N integration addition tests"""
+"""Arm(R) Ethos(TM)-N integration addition tests"""
 
 import tvm
 from tvm import relay
diff --git a/tests/python/contrib/test_ethosn/test_concatenate.py b/tests/python/contrib/test_ethosn/test_concatenate.py
index 332b4e2..ff87dfb 100644
--- a/tests/python/contrib/test_ethosn/test_concatenate.py
+++ b/tests/python/contrib/test_ethosn/test_concatenate.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Concatenate tests for Ethos-N"""
+"""Concatenate tests for Arm(R) Ethos(TM)-N"""
 
 import numpy as np
 import tvm
diff --git a/tests/python/contrib/test_ethosn/test_constant_duplication.py b/tests/python/contrib/test_ethosn/test_constant_duplication.py
index e0fb938..c0e160f 100644
--- a/tests/python/contrib/test_ethosn/test_constant_duplication.py
+++ b/tests/python/contrib/test_ethosn/test_constant_duplication.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Test that constants aren't duplicated for Ethos-N"""
+"""Test that constants aren't duplicated for Arm(R) Ethos(TM)-N"""
 
 import numpy as np
 import tvm
diff --git a/tests/python/contrib/test_ethosn/test_conv2d.py b/tests/python/contrib/test_ethosn/test_conv2d.py
index e4595af..7613cfd 100644
--- a/tests/python/contrib/test_ethosn/test_conv2d.py
+++ b/tests/python/contrib/test_ethosn/test_conv2d.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Ethos-N integration conv2d tests"""
+"""Arm(R) Ethos(TM)-N integration conv2d tests"""
 
 import numpy as np
 import math
diff --git a/tests/python/contrib/test_ethosn/test_depth_to_space.py b/tests/python/contrib/test_ethosn/test_depth_to_space.py
index 02f90a3..144f9f1 100644
--- a/tests/python/contrib/test_ethosn/test_depth_to_space.py
+++ b/tests/python/contrib/test_ethosn/test_depth_to_space.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Ethos-N integration depth-to-space tests"""
+"""Arm(R) Ethos(TM)-N integration depth-to-space tests"""
 
 import tvm
 from tvm import relay
diff --git a/tests/python/contrib/test_ethosn/test_fullyconnected.py b/tests/python/contrib/test_ethosn/test_fullyconnected.py
index 5a693a5..5ab1b6b 100644
--- a/tests/python/contrib/test_ethosn/test_fullyconnected.py
+++ b/tests/python/contrib/test_ethosn/test_fullyconnected.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Ethos-N integration fully connected tests"""
+"""Arm(R) Ethos(TM)-N integration fully connected tests"""
 
 import numpy as np
 import tvm
diff --git a/tests/python/contrib/test_ethosn/test_networks.py b/tests/python/contrib/test_ethosn/test_networks.py
index 3a8b954..2ea5a23 100644
--- a/tests/python/contrib/test_ethosn/test_networks.py
+++ b/tests/python/contrib/test_ethosn/test_networks.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Ethos-N integration end-to-end network tests"""
+"""Arm(R) Ethos(TM)-N integration end-to-end network tests"""
 
 import pytest
 
diff --git a/tests/python/contrib/test_ethosn/test_partition_params.py b/tests/python/contrib/test_ethosn/test_partition_params.py
index da1750a..97f8e50 100644
--- a/tests/python/contrib/test_ethosn/test_partition_params.py
+++ b/tests/python/contrib/test_ethosn/test_partition_params.py
@@ -14,7 +14,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Ethos(TM)-N partition parameter tests"""
+
+"""Arm(R) Ethos(TM)-N partition parameter tests"""
 
 import pytest
 import tvm
diff --git a/tests/python/contrib/test_ethosn/test_pooling.py b/tests/python/contrib/test_ethosn/test_pooling.py
index 72b01db..16be36b 100644
--- a/tests/python/contrib/test_ethosn/test_pooling.py
+++ b/tests/python/contrib/test_ethosn/test_pooling.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Ethos-N integration pooling tests"""
+"""Arm(R) Ethos(TM)-N integration pooling tests"""
 
 import numpy as np
 import tvm
diff --git a/tests/python/contrib/test_ethosn/test_relu.py b/tests/python/contrib/test_ethosn/test_relu.py
index 1f3d00c..eb272f3 100644
--- a/tests/python/contrib/test_ethosn/test_relu.py
+++ b/tests/python/contrib/test_ethosn/test_relu.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Ethos-N integration relu tests"""
+"""Arm(R) Ethos(TM)-N integration relu tests"""
 
 import tvm
 from tvm import relay
diff --git a/tests/python/contrib/test_ethosn/test_reshape.py b/tests/python/contrib/test_ethosn/test_reshape.py
index 417b52f..a870bce 100644
--- a/tests/python/contrib/test_ethosn/test_reshape.py
+++ b/tests/python/contrib/test_ethosn/test_reshape.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Ethos-N integration reshape tests"""
+"""Arm(R) Ethos(TM)-N integration reshape tests"""
 
 import tvm
 from tvm import relay
diff --git a/tests/python/contrib/test_ethosn/test_sigmoid.py b/tests/python/contrib/test_ethosn/test_sigmoid.py
index 40a2fbd..3f2908c 100644
--- a/tests/python/contrib/test_ethosn/test_sigmoid.py
+++ b/tests/python/contrib/test_ethosn/test_sigmoid.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Ethos-N integration sigmoid tests"""
+"""Arm(R) Ethos(TM)-N integration sigmoid tests"""
 
 import tvm
 from tvm import relay
diff --git a/tests/python/contrib/test_ethosn/test_split.py b/tests/python/contrib/test_ethosn/test_split.py
index e81930a..9bd8c89 100644
--- a/tests/python/contrib/test_ethosn/test_split.py
+++ b/tests/python/contrib/test_ethosn/test_split.py
@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""Split tests for Ethos-N"""
+"""Split tests for Arm(R) Ethos(TM)-N"""
 
 import numpy as np
 import tvm
diff --git a/tests/python/contrib/test_ethosn/test_topologies.py b/tests/python/contrib/test_ethosn/test_topologies.py
index 6d38c78..4514672 100644
--- a/tests/python/contrib/test_ethosn/test_topologies.py
+++ b/tests/python/contrib/test_ethosn/test_topologies.py
@@ -14,7 +14,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Ethos-N tests for complex network topologies."""
+
+"""Arm(R) Ethos(TM)-N tests for complex network topologies."""
 
 import numpy as np
 import tvm
diff --git a/python/tvm/testing/utils.py b/python/tvm/testing/utils.py
index 768705a..56072d7 100644
--- a/python/tvm/testing/utils.py
+++ b/python/tvm/testing/utils.py
@@ -811,7 +811,7 @@ def requires_rpc(*args):
 
 
 def requires_ethosn(*args):
     """Mark a test as requiring ethosn to run.
 
     Parameters
     ----------
@@ -823,7 +823,7 @@ def requires_ethosn(*args):
         pytest.mark.skipif(
             not ethosn_available(),
             reason=(
-                "Ethos-N support not enabled.  "
+                "Arm(R) Ethos(TM)-N support not enabled.  "
                 "Set USE_ETHOSN=ON in config.cmake to enable, "
                 "and ensure that hardware support is present."
             ),
@@ -811,7 +811,7 @@ def requires_rpc(*args):
 
 def requires_ethosn(*args):
-    """Mark a test as requiring ethosn to run.
+    """Mark a test as requiring Arm(R) Ethos(TM)-N to run.
 
     Parameters
diff --git a/src/relay/backend/contrib/ethosn/codegen.cc b/src/relay/backend/contrib/ethosn/codegen.cc
index 88dee92..4d9adc5 100644
--- a/src/relay/backend/contrib/ethosn/codegen.cc
+++ b/src/relay/backend/contrib/ethosn/codegen.cc
@@ -19,7 +19,7 @@
 
 /*!
  * \file src/relay/backend/contrib/ethosn/codegen.cc
  * \brief The Relay -> Ethos-N command stream compiler.
  */
 #include <tvm/relay/expr_functor.h>
 #include <tvm/runtime/module.h>
@@ -633,7 +633,7 @@ EthosnError EthosnCompiler::SupportedSetup() {
         sl::GetFwAndHwCapabilities(sl::EthosNVariantFromString(cfg.value()->variant.c_str()),
                                    std::stoul(cfg.value()->sram_size)));
     if (m_Queries == nullptr) {
-      return EthosnError("Could not initialise Ethos-N compiler isSupported");
+      return EthosnError("Could not initialise Arm(R) Ethos(TM)-N compiler isSupported");
     }
   }
   return EthosnError();
@@ -19,7 +19,7 @@
 /*!
  * \file src/relay/backend/contrib/ethosn/codegen.cc
- * \brief The Relay -> Ethos-N command stream compiler.
+ * \brief The Relay -> Arm(R) Ethos(TM)-N command stream compiler.
  */
 #include <tvm/relay/expr_functor.h>